Crate bytebox

Crate bytebox 

ByteBox ๐Ÿ“ฆ

ByteBox is an easy and performant data storage solution. It provides a way to read and write data, optionally in a secure format.

Features โœจ

  • Fast - Serialization uses bitcode for maximum decoding and encoding performance.
  • Ease-of-use - Use serde and a super-easy API to store and retrieve your data.
  • Secure - Secure your data using the XChaCha20Poly1305 algorithm without the hassle of storing and retrieving encryption keys manually.

Supported Platforms

  • Desktop: Windows, MacOS, Linux, FreeBSD, OpenBSD.
  • Mobile: iOS (Android work-in-progress).
  • Web

Getting Started ๐Ÿš€

To use ByteBox in your Rust project, run: cargo add bytebox or just add the latest version to your Cargo.toml.

Examples ๐Ÿ“

Modules

error
Contains the error::Error type.
secure
Contains functionality for secure storage and encryption of data.

Traits

ByteBox
A data store that can optionally use encryption for secure storage.
GlobalByteBox
A global data store that can optionally use encryption for secure storage.